==> mongodb_5.3.1.orig.tar.gz: mongo-r5.3.1/src/mongo/db/catalog/collection_uuid_mismatch.cpp <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/db/catalog/collection_uuid_mismatch.h"

#include "mongo/db/catalog/collection_catalog.h"
#include "mongo/db/catalog/collection_uuid_mismatch_info.h"
#include "mongo/db/storage/storage_parameters_gen.h"

namespace mongo {
void checkCollectionUUIDMismatch(OperationContext* opCtx,
                                 const NamespaceString& ns,
                                 const CollectionPtr& coll,
                                 const boost::optional<UUID>& uuid,
                                 bool checkFeatureFlag) {
    if (!uuid) {
        return;
    }

    uassert(ErrorCodes::InvalidOptions,
            "The collectionUUID parameter is not enabled",
            !checkFeatureFlag ||
                feature_flags::gCommandsAcceptCollectionUUID.isEnabled(
                    serverGlobalParams.featureCompatibility));

    auto actualNamespace = CollectionCatalog::get(opCtx)->lookupNSSByUUID(opCtx, *uuid);
    uassert(
        (CollectionUUIDMismatchInfo{ns.db().toString(),
                                    *uuid,
                                    ns.coll().toString(),
                                    actualNamespace && actualNamespace->db() == ns.db()
                                        ? boost::make_optional(actualNamespace->coll().toString())
                                        : boost::none}),
        "Collection UUID does not match that specified",
        coll && coll->uuid() == *uuid);
}
}  // namespace mongo

==> mongodb_6.1.1.orig.tar.gz: mongo-r6.1.1/src/mongo/db/catalog/collection_uuid_mismatch.cpp <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/db/catalog/collection_uuid_mismatch.h"

#include "mongo/db/catalog/collection_catalog.h"
#include "mongo/db/catalog/collection_uuid_mismatch_info.h"
#include "mongo/db/storage/storage_parameters_gen.h"

namespace mongo {
void checkCollectionUUIDMismatch(OperationContext* opCtx,
                                 const NamespaceString& ns,
                                 const CollectionPtr& coll,
                                 const boost::optional<UUID>& uuid) {
    if (!uuid) {
        return;
    }

    auto actualNamespace = CollectionCatalog::get(opCtx)->lookupNSSByUUID(opCtx, *uuid);
    uassert(
        (CollectionUUIDMismatchInfo{ns.db().toString(),
                                    *uuid,
                                    ns.coll().toString(),
                                    actualNamespace && actualNamespace->db() == ns.db()
                                        ? boost::make_optional(actualNamespace->coll().toString())
                                        : boost::none}),
        "Collection UUID does not match that specified",
        coll && coll->uuid() == *uuid);
}
}  // namespace mongo
